<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl

$authenticate_text = array (

'loginsuccessful'   =>	'Logowanie udane.',
'loginfailed'	    =>	'Logowanie NIEUDANE!',
'userandpass'	    =>	'Nie podałeś prawidłowej nazwy i hasła.',
'youareloggedout'   =>	'Zostałeś wylogowany.',
'waitwhiletransfer' =>	'Proszę czekać, jesteś kierowany do celu...',
'clicknowait'	    =>	'Kliknij tu, jeśli nie chcesz czekać.',

// Added in 0.9.7
'accountdisabled'   =>  'Twoje konto jest nieaktywne. Skontaktuj się z administratorem.',

);
// vim:fenc=utf-8:enc=utf-8
?>
